document.addEventListener('DOMContentLoaded', () => {
    initializePortfolio();
    setupEventListeners();
    updateDashboard();
});

let portfolio = {
    assets: [],
    totalValue: 0,
    dailyChange: 0
};

function initializePortfolio() {
    const savedPortfolio = localStorage.getItem('portfolio');
    if (savedPortfolio) {
        portfolio = JSON.parse(savedPortfolio);
    }
}

function setupEventListeners() {
    const addAssetBtn = document.getElementById('addAssetBtn');
    const searchInput = document.getElementById('searchHoldings');

    addAssetBtn.addEventListener('click', () => {
        showAddAssetModal();
    });

    searchInput.addEventListener('input', (e) => {
        filterHoldings(e.target.value);
    });
}

function updateDashboard() {
    document.getElementById('totalValue').textContent = formatCurrency(portfolio.totalValue);
    document.getElementById('dailyChange').textContent = formatPercentage(portfolio.dailyChange);
    document.getElementById('totalHoldings').textContent = portfolio.assets.length;
    updateHoldingsGrid();
}

function formatCurrency(value) {
    return new Intl.NumberFormat('en-US', {
        style: 'currency',
        currency: 'USD'
    }).format(value);
}

function formatPercentage(value) {
    return (value > 0 ? '+' : '') + value.toFixed(2) + '%';
}

function updateHoldingsGrid() {
    const holdingsGrid = document.getElementById('holdingsGrid');
    holdingsGrid.innerHTML = '';

    portfolio.assets.forEach(asset => {
        const assetCard = createAssetCard(asset);
        holdingsGrid.appendChild(assetCard);
    });
}

function createAssetCard(asset) {
    const card = document.createElement('div');
    card.className = 'stat-card';
    card.innerHTML = `
        <h3>${asset.symbol}</h3>
        <p>${formatCurrency(asset.value)}</p>
        <p class="change ${asset.change >= 0 ? 'positive' : 'negative'}">
            ${formatPercentage(asset.change)}
        </p>
    `;
    return card;
}

function showAddAssetModal() {
    // Implementation for adding new assets
    console.log('Add asset modal triggered');
}

function filterHoldings(searchTerm) {
    const holdings = document.querySelectorAll('.holdings-grid .stat-card');
    holdings.forEach(holding => {
        const symbol = holding.querySelector('h3').textContent.toLowerCase();
        if (symbol.includes(searchTerm.toLowerCase())) {
            holding.style.display = 'block';
        } else {
            holding.style.display = 'none';
        }
    });
}

function savePortfolio() {
    localStorage.setItem('portfolio', JSON.stringify(portfolio));
}